@@ -359,12 +359,19 @@ if (FALSE) {
   ranCoef # with Xi_ncol attribute too
 }
 
+## drastic handling of flat likelihoods for high shape= LOW variance. .NB_shapeFn(canon_step_x)=1, and .NB_shapeFn(canon_max)=max_transf. 
+#
+# if trshape = 0,  NLOPT_LN_BOBYQA first perturbation is halfway from the maximum trshape:
+# 1 if max is 2, 1.5 if max is 3...
+# Then if one wants trshape=1 to be the first perturbation, the maximum trshape must be 2...
+# One may change max_transf to (say) 10, manke .NB_shapeFn return resu*10/2 and .NB_shapeInv use abs(x*2/10) => the optimizer sequence is unchanged.
+# Actually just changing the last two or max_transf has no effect ??
 .scaleconstfn <- function(canon_step_x=5,canon_max=1e6) {
   log_sym_x <-  log(canon_step_x+1/canon_step_x-1) 
-  log(2)/log(log(canon_max+1/canon_max-1)/log_sym_x) 
+  log(2)/log(log(canon_max+1/canon_max-1)/log_sym_x) # always log('max_transf='2)/. , stemming from the halfway step taken by NLOPT_LN_BOBYQA
 }
 
-.scaleconst <- .scaleconstfn(canon_step_x = 5) # log(2)/log(log_1.5(10^6+10^{-6}-1)) 
+.scaleconst <- .scaleconstfn(canon_step_x = 5) 
 .log_sym_x <- log(4.2) # log(x+1/x-1) at the target x step 
 
 .NB_shapeFn <- function(x) {
@@ -375,9 +382,8 @@ if (FALSE) {
       resu[it] <- (log(xi+1/xi-1)/.log_sym_x)^.scaleconst
     } else {resu[it] <- -(log(xi+1/xi-1)/.log_sym_x)^.scaleconst}
   }
-  resu
-} ## drastic handling of flat likelihoods for high shape= LOW variance. .../...
-# .../... negbin example in gentle intro is a test (using optimize() -> initial value cannot be controlled)
+  resu 
+} 
 
 .NB_shapeInv <- function(x) {
   t <- exp(.log_sym_x*abs(x)^(1/.scaleconst))
@@ -954,8 +960,10 @@ if (FALSE) {
   
   # Currently there is no default beta; only a user_init_optim one:
   if (! is.null(beta <- inits[["init.optim"]]$beta)) { # at this point inits[["init.optim"]] = user's, + automatically added inits (none yet for beta)
-    inits[["init.optim"]]$trBeta <- .betaFn(beta)
-    inits[["init.optim"]]$beta <- NULL
+    if (.spaMM.data$options$tr_beta) { # for transformed scale
+      inits[["init.optim"]]$trBeta <- .betaFn(beta)
+      inits[["init.optim"]]$beta <- NULL
+    }
     inits[["init"]]$beta <- beta # ---> canon.init
   }
   
