@@ -89,7 +89,7 @@ get_cPredVar <- function(pred_object, newdata=NULL, nsim, seed=NULL, type="resid
       if (! is.null(newinits$init[["corrPars"]])) new_args$fixed <- .modify_list(eval(fit_call$fixed),newinits$init["corrPars"])
     } else if (fittingFunction=="corrHLfit") {
       new_args <- list(init.corrHLfit=newinits$init.corrHLfit[names_not_cP], init.HLfit=newinits$init.HLfit, control.corrHLfit=ctrl_opt)
-      if (! is.null(newinits$init.corrHLfit[["corrPars"]])) new_args$ranFix <- .modify_list(eval(fit_call$ranFix),newinits$init.corrHLfit["corrPars"])
+      if (! is.null(newinits$init.corrHLfit[["corrPars"]])) new_args$fixed <- .modify_list(eval(fit_call$fixed),newinits$init.corrHLfit["corrPars"])
     } else new_args <- list(init.HLfit=newinits$init.HLfit) ## could include HLCor with inner estimation of corrPars 
     simuland <- function(y, ...) { # always a dot args in the fn for dopar()
       hpff <- do.call(update_resp, c(list(object=pred_object, newresp = y),new_args)) 
